@@ -11,16 +11,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import contextlib
 from distutils import spawn
+import errno
 import logging
 import os
 import re
 import select
 import signal
+import socket
 import subprocess
 import sys
 import tenacity
 import threading
+import time
 
 import fixtures
 import jinja2
@@ -41,6 +45,10 @@ else:
 
 LOG = logging.getLogger(__name__)
 
+if six.PY2:
+    # This is defined only on Python 3
+    ProcessLookupError = None
+
 
 class Driver(fixtures.Fixture):
     def __init__(self, env_prefix="PIFPAF", templatedir=".", debug=False,
@@ -88,16 +96,30 @@ class Driver(fixtures.Fixture):
                                self.__class__.__name__)
 
     def _kill(self, process):
-        pgrp = os.getpgid(process.pid)
-        process.terminate()
+        try:
+            process.terminate()
+        except ProcessLookupError:
+            # Python 3
+            return
+        except OSError as e:
+            if e.errno != errno.ESRCH:
+                raise
+            return
         try:
 
             self._wait(process)
         except tenacity.RetryError:
-            LOG.warning("%d doesn't terminate cleanly after 10 seconds, "
-                        "sending SIGKILL to its process group")
+            LOG.warning("PID %d didn't terminate cleanly after 10 seconds, "
+                        "sending SIGKILL to its process group", process.pid)
             # Cleanup remaining processes
-            os.killpg(pgrp, signal.SIGKILL)
+            try:
+                pgrp = os.getpgid(process.pid)
+            except OSError as e:
+                # ESRCH is returned if process just died in the meantime
+                if e.errno != errno.ESRCH:
+                    raise
+            else:
+                os.killpg(pgrp, signal.SIGKILL)
         process.wait()
 
     @staticmethod
@@ -143,7 +165,8 @@ class Driver(fixtures.Fixture):
         LOG.debug("%s[%d] output: %s", appname, pid, data.rstrip())
 
     def _exec(self, command, stdout=False, ignore_failure=False,
-              stdin=None, wait_for_line=None, path=[], env=None,
+              stdin=None, wait_for_line=None, wait_for_port=None,
+              path=[], env=None,
               forbidden_line_after_start=None,
               allow_debug=True):
         LOG.debug("executing: %s" % command)
@@ -189,6 +212,8 @@ class Driver(fixtures.Fixture):
             raise RuntimeError(
                 "Unable to run command `%s': %s" % (b" ".join(command), e))
 
+        self.addCleanup(self._kill, c)
+
         if stdin:
             LOG.debug("%s input: %s" % (app, stdin))
             c.stdin.write(stdin)
@@ -240,7 +265,19 @@ class Driver(fixtures.Fixture):
             t.setDaemon(True)
             t.start()
 
-        if not wait_for_line:
+        if wait_for_port:
+            for i in range(0, 10):
+                with contextlib.closing(
+                        socket.socket(socket.AF_INET,
+                                      socket.SOCK_STREAM)) as sock:
+                    if sock.connect_ex(('127.0.0.1', wait_for_port)) == 0:
+                        break
+                time.sleep(1)
+            else:
+                raise RuntimeError("Program did not open port %s" %
+                                   wait_for_port)
+
+        if not wait_for_line and not wait_for_port:
             status = c.wait()
             if not ignore_failure and status != 0:
                 raise RuntimeError("Error while running command: %s" % command)
