@@ -15,8 +15,6 @@ import os
 import pkg_resources
 import uuid
 
-import xattr
-
 from pifpaf import drivers
 
 
@@ -36,19 +34,6 @@ class CephDriver(drivers.Driver):
                             help="port to use for Ceph Monitor")
         return parser
 
-    def _ensure_xattr_support(self, tempdir=None):
-        if tempdir is None:
-            tempdir = self.tempdir
-        testfile = os.path.join(tempdir, "test")
-        self._touch(testfile)
-        try:
-            x = xattr.xattr(testfile)
-            x[b"user.test"] = b"test"
-        except (OSError, IOError) as e:
-            if e.errno == 95:
-                raise RuntimeError("TMPDIR must support xattr for Ceph driver")
-            raise
-
     def _setUp(self):
         super(CephDriver, self)._setUp()
 
@@ -61,10 +46,11 @@ class CephDriver(drivers.Driver):
         os.makedirs(mondir)
         os.makedirs(osddir)
 
-        if os.path.exists("/dev/shm") and os.access('/dev/shm', os.W_OK):
-            journal_path = "/dev/shm/$cluster-$id-journal"
-        else:
-            journal_path = "%s/osd/$cluster-$id/journal" % self.tempdir
+        # FIXME(sileht): check availible space on /dev/shm
+        # if os.path.exists("/dev/shm") and os.access('/dev/shm', os.W_OK):
+        #     journal_path = "/dev/shm/$cluster-$id-journal"
+        # else:
+        journal_path = "%s/osd/$cluster-$id/journal" % self.tempdir
 
         with open(conffile, "w") as f:
             f.write("""[global]
@@ -94,7 +80,8 @@ mon cluster log file = %(tempdir)s/$cluster.log
 filestore xattr use omap = True
 
 # workaround for ext4 and last Jewel version
-osd max object name len = 1024
+osd max object name len = 256
+osd max object namespace len = 64
 osd op threads = 10
 filestore max sync interval = 10001
 filestore min sync interval = 10000
@@ -134,8 +121,6 @@ mon addr = 127.0.0.1:%(port)d
             mon_opts,
             wait_for_line=r"mon.a@0\(leader\).mds e1 print_map")
 
-        self.addCleanup(self._kill, mon.pid)
-
         # Create and start OSD
         self._exec(ceph_opts + ["osd", "create"])
         self._exec(ceph_opts + ["osd", "crush", "add", "osd.0", "1",
@@ -146,7 +131,6 @@ mon addr = 127.0.0.1:%(port)d
         else:
             wait_for_line = "done with init"
         osd, _ = self._exec(osd_opts, wait_for_line=wait_for_line)
-        self.addCleanup(self._kill, osd.pid)
 
         # Wait it's ready
         out = b""
