@@ -68,7 +68,6 @@ class EtcdDriver(drivers.Driver):
                                                   in enumerate(http_urls)),
                     "--initial-cluster-state", "new",
                 ], wait_for_line="listening for client requests on")
-                self.addCleanup(self._kill, c.pid)
 
             endpoints = ",".join(client_url
                                  for peer_url, client_url in http_urls)
@@ -81,11 +80,10 @@ class EtcdDriver(drivers.Driver):
                                "--listen-client-urls", client_url,
                                "--advertise-client-urls", client_url],
                               wait_for_line="listening for client requests on")
-            self.addCleanup(self._kill, c.pid)
             endpoints = client_url
 
         self.putenv("ETCD_PORT", str(self.port))
         self.putenv("ETCD_PEER_PORT", str(self.peer_port))
-        self.putenv("HTTP_URL", "etcd://localhost:%d" % self.port)
+        self.putenv("HTTP_URL", "http://localhost:%d" % self.port)
         self.putenv("URL", "etcd://localhost:%d" % self.port)
         self.putenv("ETCDCTL_ENDPOINTS", endpoints, True)
